@@ -12,6 +12,7 @@ use crate::consts;
 use crate::error::{MainError, MainResult};
 use crate::templates;
 use crate::Input;
+use std::ffi::OsString;
 
 lazy_static! {
     static ref RE_SHORT_MANIFEST: Regex =
@@ -20,11 +21,11 @@ lazy_static! {
     static ref RE_SPACE: Regex = Regex::new(r"^(\s+)").unwrap();
     static ref RE_NESTING: Regex = Regex::new(r"/\*|\*/").unwrap();
     static ref RE_COMMENT: Regex = Regex::new(r"^\s*//!").unwrap();
-    static ref RE_HASHBANG: Regex = Regex::new(r"^#![^\[].*?(\r\n|\n)").unwrap();
+    static ref RE_SHEBANG: Regex = Regex::new(r"^#![^\[].*?(\r\n|\n)").unwrap();
     static ref RE_CRATE_COMMENT: Regex = {
         Regex::new(
             r"(?x)
-                # We need to find the first `/*!` or `//!` that *isn't* preceeded by something that would make it apply to anything other than the crate itself.  Because we can't do this accurately, we'll just require that the doc comment is the *first* thing in the file (after the optional hashbang, which should already have been stripped).
+                # We need to find the first `/*!` or `//!` that *isn't* preceeded by something that would make it apply to anything other than the crate itself.  Because we can't do this accurately, we'll just require that the doc comment is the *first* thing in the file (after the optional shebang, which should already have been stripped).
                 ^\s*
                 (/\*!|//!)
             "
@@ -41,12 +42,13 @@ pub fn split_input(
     input: &Input,
     deps: &[(String, String)],
     prelude_items: &[String],
+    input_id: &OsString,
 ) -> MainResult<(String, String)> {
     let template_buf;
     let (part_mani, source, template, sub_prelude) = match *input {
         Input::File(_, _, content, _) => {
             assert_eq!(prelude_items.len(), 0);
-            let content = strip_hashbang(content);
+            let content = strip_shebang(content);
             let (manifest, source) =
                 find_embedded_manifest(content).unwrap_or((Manifest::Toml(""), content));
 
@@ -98,7 +100,7 @@ pub fn split_input(
     info!("part_mani: {:?}", part_mani);
 
     // It's-a mergin' time!
-    let def_mani = default_manifest(input)?;
+    let def_mani = default_manifest(input, input_id)?;
     let dep_mani = deps_manifest(deps)?;
 
     let mani = merge_manifest(def_mani, part_mani)?;
@@ -116,9 +118,10 @@ pub fn split_input(
 
 #[test]
 fn test_split_input() {
+    let input_id = OsString::from("input_id");
     macro_rules! si {
         ($i:expr) => {
-            split_input(&$i, &[], &[]).ok()
+            split_input(&$i, &[], &[], &input_id).ok()
         };
     }
 
@@ -136,7 +139,7 @@ fn test_split_input() {
         si!(f(r#"fn main() {}"#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -159,7 +162,7 @@ fn main() {}
 "#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -185,7 +188,7 @@ fn main() {}
 "#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -211,7 +214,7 @@ fn main() {}
 "#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -237,7 +240,7 @@ fn main() {}
 "#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -271,7 +274,7 @@ fn main() {}
 "#)),
         r!(
             r#"[[bin]]
-name = "n"
+name = "n_input_id"
 path = "n.rs"
 
 [dependencies]
@@ -299,19 +302,19 @@ fn main() {}
 }
 
 /**
-Returns a slice of the input string with the leading hashbang, if there is one, omitted.
+Returns a slice of the input string with the leading shebang, if there is one, omitted.
 */
-fn strip_hashbang(s: &str) -> &str {
-    match RE_HASHBANG.find(s) {
+fn strip_shebang(s: &str) -> &str {
+    match RE_SHEBANG.find(s) {
         Some(m) => &s[m.end()..],
         None => s,
     }
 }
 
 #[test]
-fn test_strip_hashbang() {
+fn test_strip_shebang() {
     assert_eq!(
-        strip_hashbang(
+        strip_shebang(
             "\
 #!/usr/bin/env rust-script
 and the rest
@@ -324,7 +327,7 @@ and the rest
         "
     );
     assert_eq!(
-        strip_hashbang(
+        strip_shebang(
             "\
 #![thingy]
 and the rest
@@ -927,8 +930,8 @@ fn extract_comment(s: &str) -> MainResult<String> {
         Ok(r)
     }
 
-    if s.starts_with("/*!") {
-        extract_block(&s[3..])
+    if let Some(stripped) = s.strip_prefix("/*!") {
+        extract_block(stripped)
     } else if s.starts_with("//!") {
         extract_line(s)
     } else {
@@ -1015,11 +1018,13 @@ time = "*"
 /**
 Generates a default Cargo manifest for the given input.
 */
-fn default_manifest(input: &Input) -> MainResult<toml::value::Table> {
+fn default_manifest(input: &Input, input_id: &OsString) -> MainResult<toml::value::Table> {
     let mani_str = {
         let pkg_name = input.package_name();
-        let mut subs = HashMap::with_capacity(2);
+        let bin_name = format!("{}_{}", &*pkg_name, input_id.to_str().unwrap());
+        let mut subs = HashMap::with_capacity(3);
         subs.insert(consts::MANI_NAME_SUB, &*pkg_name);
+        subs.insert(consts::MANI_BIN_NAME_SUB, &*bin_name);
         subs.insert(consts::MANI_FILE_SUB, &input.safe_name()[..]);
         templates::expand(consts::DEFAULT_MANIFEST, &subs)?
     };
